/* Cylinder */

// Parameters

DefineConstant[ dmt = { 1.0, Name "Cylinder diameter" }  ];
DefineConstant[ lgt = { 8.0, Name "Channel length" }  ];
DefineConstant[ hgt = { 6.0, Name "Channel height" }  ];
DefineConstant[ msF = { 0.75, Min 0.1, Max 1, Step 0.1, Name "Farfield mesh size" }  ];
DefineConstant[ msN = { 0.25, Min 0.1, Max 1, Step 0.1, Name "Nearfield mesh size" }  ];

// Geometry

// cylinder
Point(0) = {0, 0, 0};
Point(1) = {dmt/2, 0, 0, msN};
Point(2) = {0, dmt/2, 0, msN};
Point(3) = {-dmt/2, 0, 0, msN};
Point(4) = {0, -dmt/2, 0, msN};

// farfield
Point(11) = {lgt/2, 0, 0, msF};
Point(12) = {lgt/2, hgt/2, 0, msF};
Point(13) = {-lgt/2, hgt/2, 0, msF};
Point(14) = {-lgt/2, 0, 0, msF};
Point(15) = {-lgt/2, -hgt/2, 0, msF};
Point(16) = {lgt/2, -hgt/2, 0, msF};

// cylinder
Circle(1) = {2, 0, 1};
Circle(2) = {3, 0, 2};
Circle(3) = {4, 0, 3};
Circle(4) = {1, 0, 4};

// farfield
Line(11) = {11, 12};
Line(12) = {12, 13};
Line(13) = {13, 14};
Line(14) = {14, 15};
Line(15) = {15, 16};
Line(16) = {16, 11};

// front and wake
Line(21) = {1, 11};
Line(22) = {3, 14};

// internal field
Line Loop(1) = {21, 11, 12, 13, -22, 1, 2};
Line Loop(2) = {4, 3, 22, 14, 15, 16, -21};
Plane Surface(1) = {1};
Plane Surface(2) = {2};

// Mesh

Mesh.Algorithm = 5; // Delaunay

// Physical groups

Physical Point("te") = {1};
Physical Line("upstream") = {13, 14};
Physical Line("farfield") = {12, 15};
Physical Line("downstream") = {11};
Physical Line("downstream_") = {16};
Physical Line("cylinder") = {1, 2};
Physical Line("cylinder_") = {3, 4};
Physical Line("wake") = {21};
Physical Surface("field") = {1};
Physical Surface("field_") = {2};

