#ifndef DDISCRETIZATION_H
#define DDISCRETIZATION_H

#include "vii.h"
#include "DBoundaryLayer.h"

namespace vii
{

/**
 * @brief Boundary layer mesh.
 * @author Paul Dechamps
 */
class VII_API Discretization
{
private:
    std::vector<double> x;     ///< x coordinate in the global frame of reference.
    std::vector<double> y;     ///< y coordinate in the global frame of reference.
    std::vector<double> z;     ///< z coordinate in the global frame of reference.
    std::vector<double> loc;   ///< xi coordinate in the local frame of reference.
    std::vector<double> ext;   ///< xi coordinate in the local frame of reference, at the edge of the boundary layer.
    std::vector<double> dx;    ///< Cell size.
    std::vector<double> alpha; ///< Angle of the cell wrt the x axis of the global frame of reference.
    size_t nMarkers;           ///< Number of points in the domain.
    size_t nElm;               ///< Number of cells in the domain.

public:
    size_t prevnMarkers; ///< Number of points in the domain at the previous iteration.

    Discretization();
    ~Discretization();

    // Getters.
    size_t getnMarkers() const { return nMarkers; };
    double getLoc(size_t iPoint) const { return loc[iPoint]; };
    double getx(size_t iPoint) const { return x[iPoint]; };
    double gety(size_t iPoint) const { return y[iPoint]; };
    double getz(size_t iPoint) const { return z[iPoint]; };
    double getExt(size_t iPoint) const { return ext[iPoint]; };
    double getAlpha(size_t iElm) const { return alpha[iElm]; };
    size_t getDiffnElm() const { return nMarkers - prevnMarkers; };

    // Setters.
    void setGlob(std::vector<double> &_x, std::vector<double> &_y, std::vector<double> &_z);
    void setExt(std::vector<double> extM);
    void computeBLcoord();
};
} // namespace vii
#endif // WDISCRETIZATION_H
